@@ -43,7 +43,7 @@
 #include <apr_portable.h>
 #include <apr_support.h>
 
-#include <pcre.h>
+#include <pcre/pcre.h>
 
 #if APR_HAVE_UNISTD_H
 #include <unistd.h> /* for getpid() */
@@ -124,7 +124,7 @@ apr_status_t worker_body(worker_t **body, worker_t *worker) {
   int ends;
   int end_len;
 
-  apr_pool_create(&p, NULL);
+  HT_POOL_CREATE(&p);
   end = apr_pstrdup(p, "_END");
   end_len = strlen(end);
   ends = 1;
