@@ -21,7 +21,6 @@ extern module_t modules[];
 apr_status_t body_init(global_t *global); 
 apr_status_t xml_module_init(global_t *global);
 apr_status_t html_module_init(global_t *global);
-apr_status_t js_module_init(global_t *global);
 apr_status_t lua_module_init(global_t *global);
 apr_status_t dso_module_init(global_t *global);
 apr_status_t annotation_module_init(global_t *global);
@@ -37,13 +36,13 @@ apr_status_t socks_module_init(global_t *global);
 apr_status_t udp_module_init(global_t *global);
 apr_status_t tcp_module_init(global_t *global);
 apr_status_t ssl_module_init(global_t *global);
+apr_status_t h2_module_init(global_t *global);
 
 module_t modules[] = {
   /* MODULES_REGISTRATION */
   { body_init },
   { xml_module_init },
   { html_module_init },
-  { js_module_init },
   { lua_module_init },
   { dso_module_init },
   { annotation_module_init },
@@ -59,5 +58,6 @@ module_t modules[] = {
   { udp_module_init },
   { tcp_module_init },
   { ssl_module_init },
+  { h2_module_init },
   { NULL }
 };
