@@ -67,11 +67,51 @@ static ws_socket_config_t *ws_get_socket_config(worker_t *worker) {
   return config;
 }
 
+/**
+ * Do hex to bin transformation with this hook, this is called
+ * after late variable replacement.
+ *
+ * @param worker IN worker context
+ * @param payload IN payload as a string of space separated hex digits
+ * @param binary OUT binary data buffer
+ * @param binary_len OUT binary data buffer length
+ */
+static apr_status_t ws_hex_to_binary(worker_t *worker, char *payload, char **binary, uint64_t *binary_len) {
+  char *buf;
+  apr_size_t i;
+  apr_size_t len;
+
+  apr_collapse_spaces(payload, payload);
+  /* callculate buf len */
+  len = strlen(payload);
+  if (len && len%2 != 1) {
+    len /= 2;
+  }
+  else {
+    worker_log(worker, LOG_ERR, "Binary data must have an equal number of digits");
+    return APR_EINVAL;
+  }
+
+  buf = apr_pcalloc(worker->pbody, len);
+
+  for (i = 0; i < len; i++) {
+    char hex[3];
+    hex[0] = payload[i * 2];
+    hex[1] = payload[i * 2 + 1];
+    hex[2] = 0;
+    buf[i] = (char )apr_strtoi64(hex, NULL, 16);
+  }
+  *binary = buf;
+  *binary_len = len;
+
+  return APR_SUCCESS;
+}
+
 /************************************************************************
  * Commands 
  ***********************************************************************/
 /**
- * Recevie websocket frames
+ * Set version
  * @param worker IN callee
  * @param parent IN caller
  * @param ptmp IN temp pool
@@ -85,7 +125,7 @@ static apr_status_t block_WS_VERSION(worker_t *worker, worker_t *parent,
 }
 
 /**
- * Recevie websocket frames
+ * Receive websocket frames
  * @param worker IN callee
  * @param parent IN caller
  * @param ptmp IN temp pool
@@ -101,7 +141,7 @@ static apr_status_t block_WS_RECV(worker_t *worker, worker_t *parent,
   uint32_t mask = 0x0;
   uint64_t payload_len = 0;
   char *type;
-  char *payload;
+  char *payload = NULL;
 
   const char *type_param = store_get(worker->params, "1");
   const char *len_param = store_get(worker->params, "2");
@@ -148,10 +188,10 @@ static apr_status_t block_WS_RECV(worker_t *worker, worker_t *parent,
   len = 1;
   if ((status = sockreader_read_block(worker->socket->sockreader, 
                                       (char *)&pl_len, &len)) != APR_SUCCESS) {
-    worker_log(worker, LOG_ERR, "Could not read first frame byte");
+    worker_log(worker, LOG_ERR, "Could not read first lenght byte");
 	goto exit;
   }
-  worker_log(worker, LOG_DEBUG, "Got first len byte %x", pl_len);
+  worker_log(worker, LOG_DEBUG, "Got first length byte %x", pl_len);
   masked = (pl_len & 0x80);
   if (masked) {
     type = apr_pstrcat(ptmp, "MASKED", type?",":NULL, type, NULL);
@@ -190,7 +230,7 @@ static apr_status_t block_WS_RECV(worker_t *worker, worker_t *parent,
     if ((status = sockreader_read_block(worker->socket->sockreader, 
                                         (char *)&length, &len)) 
         != APR_SUCCESS) {
-      worker_log(worker, LOG_ERR, "Could not read 32 bit payload length");
+      worker_log(worker, LOG_ERR, "Could not read 64 bit payload length");
 	  goto exit;
     }
 #if APR_IS_BIGENDIAN
@@ -236,14 +276,14 @@ static apr_status_t block_WS_RECV(worker_t *worker, worker_t *parent,
 
 exit:
   {
-	apr_status_t hndl_buf_status;
-	hndl_buf_status = worker_handle_buf(worker, ptmp, payload, payload_len);
-	if (hndl_buf_status != APR_SUCCESS) {
-	  worker_log(worker, LOG_ERR, "inspect payload failed");
-	  return status;
-	}
-	status = worker_assert(worker, status);
-	return status;
+      apr_status_t hndl_buf_status;
+      hndl_buf_status = worker_handle_buf(worker, ptmp, payload, payload_len);
+      if (hndl_buf_status != APR_SUCCESS) {
+        worker_log(worker, LOG_ERR, "inspect payload failed");
+        return status;
+      }
+      status = worker_assert(worker, status);
+      return status;
   }
 }
 
@@ -268,6 +308,7 @@ static apr_status_t block_WS_SEND(worker_t *worker, worker_t *parent,
   uint16_t pl_len_16 = 0;
   uint64_t pl_len_64 = 0;
   uint64_t len;
+  int is_binary = 0;
 
   if (!worker->socket || !worker->socket->transport) {
     worker_log(worker, LOG_ERR, "No established socket for websocket protocol");
@@ -289,6 +330,7 @@ static apr_status_t block_WS_SEND(worker_t *worker, worker_t *parent,
     }
     else if (strcmp(e, "BINARY") == 0) {
       op |= WS_8_TYPE_BINARY;
+      is_binary = 1;
     }
     else if (strcmp(e, "CLOSE") == 0) {
       op |= WS_8_TYPE_CLOSE;
@@ -305,7 +347,16 @@ static apr_status_t block_WS_SEND(worker_t *worker, worker_t *parent,
   
   if (strcmp(payload_len, "AUTO") == 0) {
     if (payload) {
-      len = strlen(payload);
+      if (is_binary) {
+        char *result;
+        if ((status = ws_hex_to_binary(worker, payload, &result, &len)) != APR_SUCCESS) {
+            return status;
+        }
+        payload = result;
+      }
+      else {
+        len = strlen(payload);
+      }
     }
     else {
       len = 0;
