@@ -13,9 +13,12 @@ function run_single {
   B=`echo $E | sed -e 's/\(.*\)\.visual/\1/'`
   if [ -f $B.visual ]; then
     ./run.sh $B.htt >/tmp/tmp.txt 2>/dev/null
+    if [ $? -eq 2 ]; then
+      return 2
+    fi
     lines=`wc -l $B.visual | awk '{ print $1 }'`
-    tail -n ${lines} /tmp/tmp.txt >/tmp/tmp2.txt
-    diff /tmp/tmp2.txt $B.visual
+    tail -n ${lines} /tmp/tmp.txt | sed 's/\r$//' >/tmp/tmp2.txt
+    diff /tmp/tmp2.txt $B.visual >$OUT
   else
     printf "SKIP"
   fi
